## Onboarding

A well-defined onboarding process is essential for delivering a high-quality marketplace experience. Marketplace owners must establish a tailored onboarding process that aligns with their specific needs.
To provide a helpful starting point, Change2Twin outlines a detailed onboarding process that can be adapted and customized for your marketplace.

### Curation guide

A curation guide is a structured process that marketplace owners use to evaluate whether a proposed offering is suitable and high-quality for their platform. It is divided into three steps which assess: 1) company, 2) offer and 3) technical aspects (which are optional). In the first step, the company is checked using the questionnaire presented below:

![Company assessment](curation_guide_first.png)

Next, the offer is assessed based on its nature. For supporting services, enabling technology and twin application different assessment questionnaires are used, presented respectively in the figure below. The curation guide is evaluated every time an item is revised to make sure everything is covered.

![Supporting services assessment](curation_guide_services.png)

![Enabling technologies assessment](curation_guide_technology.png)

![Twin applications assessment](curation_guide_twin.png)

Evaluation of the technical side of the offerings is entirely up to the marketplace owner, however following aspects could be taken for consideration, when offerings are hosted by the marketplace owner in particular:
* usage of open standards and interoperability,
* technology maturity level,
* outcome of a security audit.

### The process

The onboarding process, outlined below, is designed to streamline the introduction of new offerings to the marketplace. While inviting a new provider is relatively simple, ensuring that each item's details are accurately captured can be complex. To facilitate this process, a structured approach is established that addresses key aspects such as the item's relationship to Digital Twinning, its relevance to end-users, the estimated effort involved, the type of process or manufacturing associated, acquisition methods, and more. The curation guide outlined in previous section is used in this process.

![Onboarding process](onboarding_process.png)

### Tools to facilitate

To expedite the onboarding process, tools like Jira's cloud-based ticketing system can be laveraged. New offerings can be submitted via email to onboarding team. Upon receipt, a ticket detailing the offer is created by on of the members thus initiating a review process. As illustrated in the diagram below, offers may be placed on hold for clarification, rejected due to insufficient or inappropriate information, or forwarded for technical evaluation. Technical reviews assess deployment and technical requirements, leading to potential rejection, temporary hold, or approval for inclusion in the marketplace. Once approved, the marketplace owner updates the platform, completing the onboarding process.

![Onboarding using Jira](onboarding_jira_2.png)

The input fields created in ticketing system needs to correspond to those defined in the marketplace model and available in the marketplace package. The process, i.e. transitions between different states during the onboarding, can be defined as suggested here or updated to reflect specific needs.

The predefined workflow and item for Jira ticketing system (cloud version) is available for download.


### Integration with the marketplace pages

To further optimise onboarding, marketplace can be integrated with a ticketing system, as illustrated in the Figure below. The onboarding process incorporates curation guide and leverages an online submission form (1), simplifying the process. While email submissions remain an option, the online form is preferred. Upon submission, details are automatically transferred to a ticketing system, triggering a notification to our onboarding team for evaluation. Upon acceptance, marketplace owner is responsible for publishing item on the marketplace.

![Onboarding integration with marketplace](onboarding_integration.png)

The online submission form need to be defined at marketplace side, filled with input boxes complementary to the these defined in marketplace model and in ticketing system. The details how to configure fields and integrate with ticketing system API, based on Jira example, is detailed in the marketplace landing pages documentation.
